# Read the raw counts
library(DESeq2);library(ggplot2);library(reshape2);library(RColorBrewer)
library(EnsDb.Hsapiens.v86);library(ggrepel);library(fgsea);library(tidyverse);library(corrplot);
library(Hmisc);

gtf = rtracklayer::import('Data/Homo_sapiens.GRCh38.103.gtf')
gtf_df = as.data.frame(gtf)
heat_colors = brewer.pal(6, "YlOrRd")

###############################
### WAGA ####
###############################
waga = read.table("Data/ont_pipeline/WAGA/counts/waga_all_gene_counts.tsv")
colnames(waga) = gsub("_.+","",colnames(waga))

# Specific to MKL1 since barcode 3 failed
designMatrix = read.table("Data/ont_pipeline/WAGA/DesignMatrixWAGA.txt")
colnames(designMatrix) = c("Samples","Condition")
designMatrix$Samples = colnames(waga)
dds = DESeqDataSetFromMatrix(countData = waga,colData = designMatrix,design = ~Condition)
dds = DESeq(dds)
plotDispEsts(dds, main= "dispEst: waga")

# Lists the coefficients
res = results(dds, name=resultsNames(dds)[2])
res = as.data.frame(res)
res = res[complete.cases(res),]
resSig = res[res$padj < 0.1 & abs(res$log2FoldChange) > 1,]

# Formating of ENSG
geneIDs = ensembldb::select(EnsDb.Hsapiens.v86, keys = rownames(res), keytype = "GENEID", columns = c("SYMBOL","GENEID"))
rownames(geneIDs) = geneIDs$GENEID
res$symbol = geneIDs[rownames(res),1]
res["LargeT-Antigen","symbol"] = "Large-T-Antigen"
resSig$symbol = geneIDs[rownames(resSig),1]
rm(geneIDs)

res = res[,c("symbol","baseMean","log2FoldChange","pvalue","padj")]
resSig = resSig[,c("symbol","baseMean","log2FoldChange","padj")]

norm_counts = as.data.frame(counts(dds,normalized = T))
norm_counts_waga = norm_counts
res = cbind(res,norm_counts[rownames(res),])
res = res[complete.cases(res),]
outpath = paste0("Analysis/","waga-results-unfiltered.tsv")
write.table(res,file=outpath,sep="\t",row.names = F)

threshold = 0.01
library(ggrepel)

# VOLCANO PLOT
mycolors = c("green", "red", "black")
names(mycolors) = c("UP", "DOWN", "NO")

res$diff = "NO"
res$diff[res$log2FoldChange > 1 & res$padj < 0.1] <- "UP"
res$diff[res$log2FoldChange < -1 & res$padj < 0.1] <- "DOWN"
res$label[res$diff != "NO"] = res$symbol[res$diff != "NO"]

ggplot(res)+
  geom_point(aes(x = log2FoldChange, y = -log10(pvalue),col=diff)) +
  geom_text_repel(data=res,mapping = aes(x = log2FoldChange,-log10(pvalue),label = label)) +
  scale_colour_manual(values = mycolors)+
  ggtitle("WAGA") +
  theme_bw(base_size = 15)+
  xlab("log2 fold change") + 
  ylab("-log10 p-value") +
  #geom_vline(xintercept=c(-1, 1), col="red",linetype="longdash")+
  #geom_hline(yintercept=-log10(0.1), col="red",linetype="longdash")+
  scale_x_continuous(breaks = scales::pretty_breaks(n = 15)) +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  theme(legend.position = "none",
        plot.title = element_text(size = rel(1.5), hjust = 0.5),
        axis.title = element_text(size = rel(1.25))) 

####
rownames(designMatrix) = designMatrix$Sample

vsd = vst(dds, blind=FALSE)
pcaData = plotPCA(vsd, intgroup=c("Condition"), returnData=TRUE)
percentVar = round(100 * attr(pcaData, "percentVar"))
ggplot(pcaData, aes(PC1, PC2, color=Condition)) +
  geom_point(size=3) +
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
  coord_fixed()

vsd = as.data.frame(assay(vsd))
vsd = vsd[row.names(resSig),]
rownames(designMatrix) = designMatrix$Sample
resSig = resSig[order(resSig$log2FoldChange,decreasing = T),]
vsd = vsd[rownames(resSig),]

pheatmap::pheatmap(vsd,
                   color = heat_colors,
                   cellwidth = 30,
                   cellheight = 30,
                   show_colnames = F,
                   cluster_rows = F,
                   cluster_cols =  T,
                   border_color = NA,
                   labels_row = resSig$symbol,
                   fontsize = 7,
                   annotation_col = designMatrix[,c(2),drop=F],
                   annotation_row = resSig[,c(4,3),drop = F],
                   main = "WAGA - VSD normaliszed",
                   angle_col = "45")


#############################
####### MKL1 ################
#############################

mkl1 = read.table("Data/ont_pipeline/MKL1/counts/mkl1_all_gene_counts.tsv")
colnames(mkl1) = gsub("_.+","",colnames(mkl1))
# Specific to MKL1 since barcode 3 failed
mkl1 = mkl1[,-3]
designMatrix = read.table("Data/ont_pipeline/MKL1/DesignMatrixMKL1.txt")
colnames(designMatrix) = c("Samples","Condition")
designMatrix$Samples = colnames(mkl1)
dds = DESeqDataSetFromMatrix(countData = mkl1,colData = designMatrix,design = ~Condition)
dds = DESeq(dds)
plotDispEsts(dds, main= "dispEst: mkl1")

# Lists the coefficients
res = results(dds, name=resultsNames(dds)[2])
res = as.data.frame(res)
res = res[complete.cases(res),]
resSig = res[res$padj < 0.1 & abs(res$log2FoldChange)>1,]

# Formating of ENSG
geneIDs = ensembldb::select(EnsDb.Hsapiens.v86, keys = rownames(res), keytype = "GENEID", columns = c("SYMBOL","GENEID"))
rownames(geneIDs) = geneIDs$GENEID
res$symbol = geneIDs[rownames(res),1]
res["LargeT-Antigen","symbol"] = "Large-T-Antigen"
resSig$symbol = geneIDs[rownames(resSig),1]
rm(geneIDs)

res = res[,c("symbol","baseMean","log2FoldChange","pvalue","padj")]
resSig = resSig[,c("symbol","baseMean","log2FoldChange","padj")]

norm_counts = as.data.frame(counts(dds,normalized = T))
norm_counts_mkl1 = norm_counts
res = cbind(res,norm_counts[rownames(res),])
res = res[complete.cases(res),]
outpath = paste0("Analysis/","mkl1-results-unfiltered.tsv")
write.table(res,file=outpath,sep="\t",row.names = F)



### VOLCANO PLOTS MKL1
mycolors = c("green", "red", "black")
names(mycolors) = c("UP", "DOWN", "NO")

res$diff = "NO"
res$diff[res$log2FoldChange > 1 & res$padj < 0.1] <- "UP"
res$diff[res$log2FoldChange < -1 & res$padj < 0.1] <- "DOWN"
res$label[res$diff != "NO"] = res$symbol[res$diff != "NO"]

ggplot(res)+
  geom_point(aes(x = log2FoldChange, y = -log10(pvalue),col=diff)) +
  geom_text_repel(data=res,mapping = aes(x = log2FoldChange,-log10(pvalue),label = label)) +
  scale_colour_manual(values = mycolors)+
  ggtitle("MKL1") +
  theme_bw(base_size = 15)+
  xlab("log2 fold change") + 
  ylab("-log10 p-value") +
  #geom_vline(xintercept=c(-1, 1), col="red",linetype="longdash")+
  #geom_hline(yintercept=-log10(0.1), col="red",linetype="longdash")+
  scale_x_continuous(breaks = scales::pretty_breaks(n = 15)) +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  theme(legend.position = "none",
        plot.title = element_text(size = rel(1.5), hjust = 0.5),
        axis.title = element_text(size = rel(1.25))) 

vsd = vst(dds, blind=FALSE)
pcaData = plotPCA(vsd, intgroup=c("Condition"), returnData=TRUE)
percentVar = round(100 * attr(pcaData, "percentVar"))
ggplot(pcaData, aes(PC1, PC2, color=Condition)) +
  geom_point(size=3) +
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
  coord_fixed()

vsd = as.data.frame(assay(vsd))
vsd = vsd[row.names(resSig),]

rownames(designMatrix) = designMatrix$Sample
resSig = resSig[order(resSig$log2FoldChange,decreasing = T),]
vsd = vsd[rownames(resSig),]
resSig["ENSG00000283782","symbol"] = "AC116366.1"

pheatmap::pheatmap(vsd,
                   color = heat_colors,
                   cellwidth = 30,
                   show_colnames = F,
                   cluster_rows = F,
                   cluster_cols =  T,
                   border_color = NA,
                   labels_row = resSig$symbol,
                   fontsize = 7,
                   annotation_col = designMatrix[,c(2),drop=F],
                   annotation_row = resSig[,c(4,3),drop = F],
                   main = "MKL1 - VSD normaliszed",
                   angle_col = "45")

###########
# MKL2
###########
mkl2 = read.table("Data/ont_pipeline/MKL2/counts/mkl2_all_gene_counts.tsv")
colnames(mkl2) = gsub("_.+","",colnames(mkl2))

designMatrix = read.table("Data/ont_pipeline/MKL2/DesignMatrixMKL2.txt")
colnames(designMatrix) = c("Samples","Condition")
designMatrix$Samples = colnames(mkl2)
dds = DESeqDataSetFromMatrix(countData = mkl2,colData = designMatrix,design = ~Condition)
dds = DESeq(dds)
plotDispEsts(dds, main= "dispEst: mkl2")

# Lists the coefficients
res = results(dds, name=resultsNames(dds)[2])
res = as.data.frame(res)
res = res[complete.cases(res),]
resSig = res[res$padj < 0.1 & abs(res$log2FoldChange)>1,]

# Formating of ENSG
geneIDs = ensembldb::select(EnsDb.Hsapiens.v86, keys = rownames(res), keytype = "GENEID", columns = c("SYMBOL","GENEID"))
rownames(geneIDs) = geneIDs$GENEID
res$symbol = geneIDs[rownames(res),1]
res["LargeT-Antigen","symbol"] = "Large-T-Antigen"
resSig$symbol = geneIDs[rownames(resSig),1]

rm(geneIDs)

res = res[,c("symbol","baseMean","log2FoldChange","pvalue","padj")]
resSig = resSig[,c("symbol","baseMean","log2FoldChange","padj")]

norm_counts = as.data.frame(counts(dds,normalized = T))
norm_counts_mkl2 = norm_counts
res = cbind(res,norm_counts[rownames(res),])
res = res[complete.cases(res),]
outpath = paste0("Analysis/","mkl2-results-unfiltered.tsv")
write.table(res,file=outpath,sep="\t",row.names = F)

### VOLCANO PLOT MKL2
mycolors = c("green", "red", "black")
names(mycolors) = c("UP", "DOWN", "NO")

res$diff = "NO"
res$diff[res$log2FoldChange > 1 & res$padj < 0.1] <- "UP"
res$diff[res$log2FoldChange < -1 & res$padj < 0.1] <- "DOWN"
res$label[res$diff != "NO"] = res$symbol[res$diff != "NO"]

ggplot(res)+
  geom_point(aes(x = log2FoldChange, y = -log10(pvalue),col=diff)) +
  geom_text_repel(data=res,mapping = aes(x = log2FoldChange,-log10(pvalue),label = label)) +
  scale_colour_manual(values = mycolors)+
  ggtitle("MKL2") +
  theme_bw(base_size = 15)+
  xlab("log2 fold change") + 
  ylab("-log10 p-value") +
  #geom_vline(xintercept=c(-1, 1), col="red",linetype="longdash")+
  #geom_hline(yintercept=-log10(0.1), col="red",linetype="longdash")+
  scale_x_continuous(breaks = scales::pretty_breaks(n = 15)) +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  theme(legend.position = "none",
        plot.title = element_text(size = rel(1.5), hjust = 0.5),
        axis.title = element_text(size = rel(1.25))) 

### 
vsd = vst(dds, blind=FALSE)
pcaData = plotPCA(vsd, intgroup=c("Condition"), returnData=TRUE)
percentVar = round(100 * attr(pcaData, "percentVar"))
ggplot(pcaData, aes(PC1, PC2, color=Condition)) +
  geom_point(size=3) +
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
  coord_fixed()

vsd = as.data.frame(assay(vsd))
vsd = vsd[row.names(resSig),]
rownames(designMatrix) = designMatrix$Sample

resSig = resSig[order(resSig$log2FoldChange,decreasing = T),]
vsd = vsd[rownames(resSig),]

pheatmap::pheatmap(vsd,
                   color = heat_colors,
                   cellwidth = 30,
                   show_colnames = F,
                   cluster_rows = F,
                   cluster_cols =  T,
                   border_color = NA,
                   labels_row = resSig$symbol,
                   fontsize = 7,
                   annotation_col = designMatrix[,c(2),drop=F],
                   annotation_row = resSig[,c(4,3),drop = F],
                   main = "MKL2 - VSD normaliszed",
                   angle_col = "45")


##########################################################################
##### CROSS CELL LINE COMPARISON #########################################
##########################################################################

counts = with(new.env(),{
  
  mkl1 = read.delim("Data/ont_pipeline/MKL1/counts/mkl1_all_gene_counts.tsv")
  colnames(mkl1) = gsub("_.+","",colnames(mkl1))
  colnames(mkl1) = paste("MKL1",colnames(mkl1),sep="-")
  mkl1 = mkl1[,-3]
  
  mkl2 = read.delim("Data/ont_pipeline/MKL2/counts/mkl2_all_gene_counts.tsv")
  colnames(mkl2) = gsub("_.+","",colnames(mkl2))
  colnames(mkl2) = paste("MKL2",colnames(mkl2),sep="-")

  waga = read.delim("Data/ont_pipeline/WAGA/counts/waga_all_gene_counts.tsv")
  colnames(waga) = gsub("_.+","",colnames(waga))
  colnames(waga) = paste("WAGA",colnames(waga),sep="-")
  
  allcounts = merge(mkl1,mkl2,all = TRUE,by="row.names")
  rownames(allcounts) = allcounts$Row.names
  allcounts = allcounts[,-1]  
  allcounts = merge(allcounts,waga,all = TRUE,by="row.names")
  allcounts[is.na(allcounts)] = 0
  
  rownames(allcounts) = allcounts$Row.names
  allcounts = allcounts[,-1]
  
  return(allcounts)
  
})
design = read.table(file = "Data/ont_pipeline/DesignMatrixAll.txt")
colnames(design) = c("Sample","Condition","Cell")
dds = DESeqDataSetFromMatrix(countData = counts,colData = design,design = ~ Cell+Condition)
dds = DESeq(dds)

# Lists the coefficients
resultsNames(dds)
res = results(dds, name=resultsNames(dds)[4])
res = as.data.frame(res)
res = res[complete.cases(res),]
resSig = res[res$padj < 0.1 & abs(res$log2FoldChange)>1,]

# Formating of ENSG
geneIDs = ensembldb::select(EnsDb.Hsapiens.v86, keys = rownames(res), keytype = "GENEID", columns = c("SYMBOL","GENEID"))
rownames(geneIDs) = geneIDs$GENEID
res$symbol = geneIDs[rownames(res),1]
res["LargeT-Antigen","symbol"] = "Large-T-Antigen"
resSig$symbol = geneIDs[rownames(resSig),1]
rm(geneIDs)

res = res[,c("symbol","baseMean","log2FoldChange","pvalue","padj")]
resSig = resSig[,c("symbol","baseMean","log2FoldChange","padj")]
norm_counts = as.data.frame(counts(dds,normalized = T))
res = cbind(res,norm_counts[rownames(res),])
res = res[complete.cases(res),]
outpath = paste0("Analysis/",paste0("All","-lines-results-unfiltered.tsv"))
write.table(res,file=outpath,sep="\t",row.names = F)



########################################################
################## Hallmarks ###########################
########################################################
pathways.hallmark = gmtPathways("../../Src/GSEA_MSigDB/Hallmark/h.all.v7.2.symbols.xls")

fgseaDat = deframe(resSig[,c(1,3)])
fgseaRes = fgsea(pathways=pathways.hallmark,stats=fgseaDat)
fgseaResTidy = fgseaRes %>%as_tibble() %>%arrange(desc(NES))

# Show in a nice table:
ggplot(fgseaResTidy, aes(reorder(pathway, NES), NES)) +
  geom_col(aes(fill=size)) +
  coord_flip() +
  labs(x="Pathway", y="Normalized Enrichment Score",
       title="Hallmark pathways enrichment calculation over genes derived from all cell lines") + 
  theme_minimal()




#resSig = cbind(resSig,norm_counts[rownames(resSig),])
#resSig[,5:ncol(resSig)] = log2(resSig[,5:ncol(resSig)]+1)
ggplot(res)+
  geom_point(aes(x = log2FoldChange, y = -log10(padj), colour = padj<0.1 && log2FoldChange > 1)) +
  #geom_text_repel(aes(x = log2FoldChange, y = -log10(padj), label = ifelse(genelabels == T, rownames(res),""))) +
  #geom_text_repel(aes(x = log2FoldChange, y = -log10(padj),label = "Yes")) +
  ggtitle("All") +
  xlab("log2 fold change") + 
  ylab("-log10 adjusted p-value") +
  theme(legend.position = "none",
        plot.title = element_text(size = rel(1.5), hjust = 0.5),
        axis.title = element_text(size = rel(1.25))) 

rownames(design) = design$Sample

vsd = vst(dds, blind=FALSE)
assay(vsd) = limma::removeBatchEffect(assay(vsd), vsd$Cell)
pcaData = plotPCA(vsd, intgroup=c("Condition", "Cell"), returnData=TRUE)
percentVar = round(100 * attr(pcaData, "percentVar"))

ggplot(pcaData, aes(PC1, PC2, color=Condition, shape=Cell)) +
  geom_point(size=3) +
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
  coord_fixed()

vsd = as.data.frame(assay(vsd))
vsd = vsd[row.names(resSig),]

rownames(design) = design$Sample

resSig = resSig[order(resSig$log2FoldChange,decreasing = T),]
vsd = vsd[rownames(resSig),]

pheatmap::pheatmap(vsd,
                   color = heat_colors,
                   cellwidth = 5,
                   cellheight = 10,
                   show_colnames = F,
                   cluster_rows = F,
                   cluster_cols =  T,
                   border_color = NA,
                   labels_row = resSig$symbol,
                   fontsize = 7,
                   annotation_col = design[,c(2),drop=F],
                   annotation_row = resSig[,c(4,3),drop = F],
                   main = "Cross Cell line comparision - VSD normaliszed",
                   angle_col = "45")

###############################
# Large T Antigen Expression  #
###############################
files = dir(path = "Data/ont_pipeline/MKL1/tpm/", pattern = "*.txt")
files = paste("Data/ont_pipeline/MKL1/tpm/",files,sep="/")
tpm = lapply(files, read.delim,header = T)
tpm = do.call(cbind,tpm)
tpm = tpm[,c(1,4,9,14,19,24,29)]
rownames(tpm) = tpm[,1]
tpm = tpm[,-1]

rownames(tpm) = sub('\\.[0-9]*$', '', rownames(tpm))
colnames(tpm) = c("Control-1","Control-2","Control-3","IFNy-1","IFNy-2","IFNy-3")
tpm = tpm[rowSums(tpm)>0,]
mkl1 = tpm["LargeT-Antigen",]
mkl1$sample = "Mkl1"

files = dir(path = "Data/ont_pipeline/MKL2/tpm/", pattern = "*.txt")
files = paste("Data/ont_pipeline/MKL2/tpm/",files,sep="/")
tpm = lapply(files, read.delim,header = T)
tpm = do.call(cbind,tpm)
tpm = tpm[,c(1,4,9,14,19,24,29)]
rownames(tpm) = tpm[,1]
tpm = tpm[,-1]
rownames(tpm) = sub('\\.[0-9]*$', '', rownames(tpm))
colnames(tpm) = c("Control-1","Control-2","Control-3","IFNy-1","IFNy-2","IFNy-3")
tpm = tpm[rowSums(tpm)>0,]
mkl2 = tpm["LargeT-Antigen",]
mkl2$sample = "Mkl2"

files = dir(path = "Data/ont_pipeline/WAGA/tpm/", pattern = "*.txt")
files = paste("Data/ont_pipeline/WAGA/tpm/",files,sep="/")
tpm = lapply(files, read.delim,header = T)
tpm = do.call(cbind,tpm)
tpm = tpm[,c(1,4,9,14,19,24,29)]
rownames(tpm) = tpm[,1]
tpm = tpm[,-1]

rownames(tpm) = sub('\\.[0-9]*$', '', rownames(tpm))
colnames(tpm) = c("Control-1","Control-2","Control-3","IFNy-1","IFNy-2","IFNy-3")
tpm = tpm[colSums(tpm)>0,]
waga = tpm["LargeT-Antigen",]
waga$sample = "Waga"

#### Large T Antigen ###
lta = rbind(mkl1,mkl2,waga)

lta$sample = c("MKL1","MKL2","WAGA")
lta = melt(lta)
lta$variable = gsub("\\-.","",lta$variable)
lta = lta[!lta$value == 0,]

ggplot(lta,aes(x=variable,y=value,fill=sample))+
  geom_boxplot()+
  theme_bw(base_size = 16)+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  xlab("Large T-antigen expression")+
  ylab("Transcripts per Million")